==> quantmod_0.4-6.tar.gz: quantmod/man/quantmod-package.Rd <==
\name{quantmod-package}
\alias{quantmod-package}
\alias{quantmod}
\alias{quantmodenv}
\docType{package}
\title{
Quantitative Financial Modelling Framework
}
\description{
Quantitative Financial Modelling and Trading Framework for R
}
\details{
\tabular{ll}{
Package: \tab quantmod\cr
Type: \tab Package\cr
Version: \tab 0.4-6\cr
Date: \tab 2016-08-25\cr
Depends: \tab xts(>= 0.9-0),zoo,TTR(>= 0.2),methods\cr
Suggests: \tab DBI,RMySQL,RSQLite,timeSeries,its,XML,downloader,jsonlite\cr
LazyLoad: \tab yes\cr
License: \tab GPL-3\cr
URL: \tab http://www.quantmod.com\cr
URL: \tab https://github.com/joshuaulrich/quantmod\cr
}
The quantmod package for R is designed to
assist the quantitative trader in the
development, testing, and deployment
of statistically based trading models.


\emph{What quantmod IS}

A rapid prototyping environment, with comprehensive
tools for data management and visualization.
where quant traders can quickly
and cleanly explore and build trading models.


\emph{What quantmod is NOT}

A replacement for anything statistical.
It has no 'new' modelling routines or
analysis tool to speak of. It does now
offer charting not currently available
elsewhere in R, but most everything else
is more of a wrapper to what you already
know and love about the langauge
and packages you currently use.

quantmod makes modelling easier by removing
the repetitive workflow issues surrounding
data management, modelling interfaces,
and performance analysis. 

}
\author{
Jeffrey A. Ryan

Maintainer: Joshua M. Ulrich <josh.m.ulrich@gmail.com>
}
\keyword{ package }

==> quantmod_0.4-7.tar.gz: quantmod/man/quantmod-package.Rd <==
\name{quantmod-package}
\alias{quantmod-package}
\alias{quantmod}
\alias{quantmodenv}
\docType{package}
\title{
Quantitative Financial Modelling Framework
}
\description{
Quantitative Financial Modelling and Trading Framework for R
}
\details{
\tabular{ll}{
Package: \tab quantmod\cr
Type: \tab Package\cr
Version: \tab 0.4-7\cr
Date: \tab 2016-10-24\cr
Depends: \tab xts(>= 0.9-0),zoo,TTR(>= 0.2),methods\cr
Suggests: \tab DBI,RMySQL,RSQLite,timeSeries,its,XML,downloader,jsonlite(>= 1.1)\cr
LazyLoad: \tab yes\cr
License: \tab GPL-3\cr
URL: \tab http://www.quantmod.com\cr
URL: \tab https://github.com/joshuaulrich/quantmod\cr
}
The quantmod package for R is designed to
assist the quantitative trader in the
development, testing, and deployment
of statistically based trading models.


\emph{What quantmod IS}

A rapid prototyping environment, with comprehensive
tools for data management and visualization.
where quant traders can quickly
and cleanly explore and build trading models.


\emph{What quantmod is NOT}

A replacement for anything statistical.
It has no 'new' modelling routines or
analysis tool to speak of. It does now
offer charting not currently available
elsewhere in R, but most everything else
is more of a wrapper to what you already
know and love about the langauge
and packages you currently use.

quantmod makes modelling easier by removing
the repetitive workflow issues surrounding
data management, modelling interfaces,
and performance analysis. 

}
\author{
Jeffrey A. Ryan

Maintainer: Joshua M. Ulrich <josh.m.ulrich@gmail.com>
}
\keyword{ package }
